@@ -19,10 +19,7 @@
 import time
 
 # external packages
-from PyQt5.QtGui import QTextCursor
-import PyQt5.QtCore
-import PyQt5.QtWidgets
-import PyQt5.uic
+from PyQt5.QtGui import QTextCursor, QColor, QFont
 
 # local import
 from gui.utilities import toolsQtWidget
@@ -44,17 +41,9 @@ class MessageWindow(toolsQtWidget.MWidget):
         self.app = app
         self.ui = message_ui.Ui_MessageDialog()
         self.ui.setupUi(self)
-
-        self.messColor = [self.COLOR_ASTRO,
-                          self.COLOR_WHITE,
-                          self.COLOR_YELLOW,
-                          self.COLOR_RED,
-                          ]
-        self.messFont = [PyQt5.QtGui.QFont.Normal,
-                         PyQt5.QtGui.QFont.Bold,
-                         PyQt5.QtGui.QFont.Normal,
-                         PyQt5.QtGui.QFont.Normal,
-                         ]
+        self.messFont = None
+        self.messColor = None
+        self.setupMessage()
 
     def initConfig(self):
         """
@@ -83,8 +72,8 @@ class MessageWindow(toolsQtWidget.MWidget):
         if 'messageW' not in self.app.config:
             self.app.config['messageW'] = {}
         config = self.app.config['messageW']
-        config['winPosX'] = self.pos().x()
-        config['winPosY'] = self.pos().y()
+        config['winPosX'] = max(self.pos().x(), 0)
+        config['winPosY'] = max(self.pos().y(), 0)
         config['height'] = self.height()
         return True
 
@@ -96,6 +85,7 @@ class MessageWindow(toolsQtWidget.MWidget):
         self.storeConfig()
         self.ui.clear.clicked.disconnect(self.clearWindow)
         self.app.update1s.disconnect(self.writeMessage)
+        self.app.colorChange.disconnect(self.colorChange)
         super().closeEvent(closeEvent)
 
     def showWindow(self):
@@ -104,9 +94,35 @@ class MessageWindow(toolsQtWidget.MWidget):
         """
         self.ui.clear.clicked.connect(self.clearWindow)
         self.app.update1s.connect(self.writeMessage)
+        self.app.colorChange.connect(self.colorChange)
         self.show()
         return True
 
+    def setupMessage(self):
+        """
+        :return:
+        """
+        self.messColor = [QColor(self.M_BLUE),
+                          QColor(self.M_WHITE),
+                          QColor(self.M_YELLOW),
+                          QColor(self.M_RED),
+                          ]
+        self.messFont = [QFont.Normal,
+                         QFont.Bold,
+                         QFont.Normal,
+                         QFont.Normal,
+                         ]
+        return True
+
+    def colorChange(self):
+        """
+        :return:
+        """
+        self.setStyleSheet(self.mw4Style)
+        self.setupMessage()
+        self.clearWindow()
+        return True
+
     def clearWindow(self):
         """
         :return: true for test purpose
