@@ -23,6 +23,7 @@ from PyQt5.QtGui import QPixmap, QPainter, QPen, QColor
 from PyQt5.QtCore import Qt, QPointF
 from PyQt5.QtWidgets import QApplication
 from skyfield import almanac
+from skyfield.trigonometry import position_angle_of
 import numpy as np
 
 # local import
@@ -32,7 +33,6 @@ from base.tpool import Worker
 class Almanac:
     """
     """
-
     phasesText = {
         'New moon': {
             'range': (0, 1),
@@ -64,43 +64,23 @@ class Almanac:
     }
 
     def __init__(self):
-
         self.civil = None
         self.nautical = None
         self.astronomical = None
-        self.dark = None
-        self.thread = None
-
-        self.colors = {
-            0: {'text': self.COLOR_BLUE4,
-                'plot': self.M_BLUE4,
-                },
-            1: {'text': self.COLOR_BLUE3,
-                'plot': self.M_BLUE3,
-                },
-            2: {'text': self.COLOR_BLUE2,
-                'plot': self.M_BLUE2,
-                },
-            3: {'text': self.COLOR_BLUE1,
-                'plot': self.M_BLUE1,
-                },
-            4: {'text': self.COLOR_WHITE1,
-                'plot': self.M_BACK,
-                },
-        }
-
+        self.colors = None
+        self.setColors()
         self.app.start1s.connect(self.searchTwilightList)
-        self.app.start3s.connect(self.searchTwilightPlot)
+        self.app.start5s.connect(self.searchTwilightPlot)
         self.app.update30m.connect(self.updateMoonPhase)
-        self.ui.almanacCivil.setStyleSheet(self.BACK_BLUE1)
-        self.ui.almanacNautical.setStyleSheet(self.BACK_BLUE2)
-        self.ui.almanacAstronomical.setStyleSheet(self.BACK_BLUE3)
-        self.ui.almanacDark.setStyleSheet(self.BACK_BLUE4)
+        self.app.colorChange.connect(self.colorChangeAlmanac)
 
     def initConfig(self):
         """
         :return: True for test purpose
         """
+        config = self.app.config['mainW']
+        self.ui.almanacPrediction.setCurrentIndex(config.get('almanacPrediction', 0))
+        self.ui.almanacPrediction.currentIndexChanged.connect(self.searchTwilightPlot)
         self.updateMoonPhase()
         self.lunarNodes()
         return True
@@ -109,8 +89,28 @@ class Almanac:
         """
         :return: True for test purpose
         """
-        if self.thread:
-            self.thread.join()
+        config = self.app.config['mainW']
+        config['almanacPrediction'] = self.ui.almanacPrediction.currentIndex()
+        return True
+
+    def setColors(self):
+        """
+        :return:
+        """
+        self.ui.almanacCivil.setStyleSheet(f'background-color: {self.M_BLUE1};')
+        self.ui.almanacNautical.setStyleSheet(f'background-color: {self.M_BLUE2};')
+        self.ui.almanacAstronomical.setStyleSheet(f'background-color: {self.M_BLUE3};')
+        self.ui.almanacDark.setStyleSheet(f'background-color: {self.M_BLUE4};')
+        self.colors = [self.M_BLUE4, self.M_BLUE3, self.M_BLUE2, self.M_BLUE1,
+                       self.M_BACK]
+        return True
+
+    def colorChangeAlmanac(self):
+        """
+        :return:
+        """
+        self.setColors()
+        self.searchTwilightPlot()
         return True
 
     def plotTwilightData(self, result):
@@ -140,20 +140,21 @@ class Almanac:
 
         for ti, event in zip(t, e):
             QApplication.processEvents()
+            if self.closing:
+                break
             hour = int(ti.astimezone(tzlocal()).strftime('%H'))
             minute = int(ti.astimezone(tzlocal()).strftime('%M'))
             y = (hour + 12 + minute / 60) % 24
             day = round(ti.tt + 0.5, 0)
             axe.bar(day, height=24 - y, bottom=y, width=1,
-                    color=self.colors[event]['plot'])
-
-        x = [midLim - 1, midLim - 1, midLim + 1, midLim + 1]
-        y = [0, 24, 24, 0]
-        axe.fill(x, y, self.M_GREY, alpha=0.5)
-        if self.closing:
-            return False
-        axe.figure.canvas.draw()
-        return True
+                    color=self.colors[event])
+        else:
+            x = [midLim - 1, midLim - 1, midLim + 1, midLim + 1]
+            y = [0, 24, 24, 0]
+            axe.fill(x, y, self.M_GREY, alpha=0.5)
+            axe.figure.canvas.draw()
+            return True
+        return False
 
     def displayTwilightData(self, timeEvents, events):
         """
@@ -165,7 +166,6 @@ class Almanac:
         self.ui.twilightEvents.clear()
 
         for timeEvent, event in zip(timeEvents, events):
-            self.ui.twilightEvents.setTextColor(self.colors[event]['text'])
             text += f'{timeEvent.astimezone(tzlocal()).strftime("%H:%M:%S")} '
             text += f'{almanac.TWILIGHTS[event]}'
             self.ui.twilightEvents.insertPlainText(text)
@@ -184,7 +184,6 @@ class Almanac:
         t1 = ts.tt_jd(int(timeJD.tt) + timeWindow + 1)
 
         f = almanac.dark_twilight_day(self.app.ephemeris, location)
-        f.step_days = 0.04
         timeEvents, events = almanac.find_discrete(t0, t1, f)
         return timeEvents, events
 
@@ -202,12 +201,18 @@ class Almanac:
         """
         :return: true for test purpose
         """
+        timeWindowParam = [17, 32, 47, 92, 182]
         location = self.app.mount.obsSite.location
         if location is None:
             return False
 
+        index = self.ui.almanacPrediction.currentIndex()
+        text = self.ui.almanacPrediction.currentText()
+        timeWindow = timeWindowParam[index]
+        self.ui.almanacGroup.setTitle(f'Twilight passes for: {text}')
+
         ts = self.app.mount.obsSite.ts
-        worker = Worker(self.searchTwilightWorker, ts, location, 182)
+        worker = Worker(self.searchTwilightWorker, ts, location, timeWindow)
         worker.signals.result.connect(self.plotTwilightData)
         self.threadPool.start(worker)
         return True
@@ -236,6 +241,7 @@ class Almanac:
         moon = self.app.ephemeris['moon']
         earth = self.app.ephemeris['earth']
         now = self.app.mount.obsSite.ts.now()
+        loc = self.app.mount.obsSite.location + earth
 
         e = earth.at(self.app.mount.obsSite.timeJD)
         _, sunLon, _ = e.observe(sun).apparent().ecliptic_latlon()
@@ -246,7 +252,12 @@ class Almanac:
         mpDegree = (moonLon.degrees - sunLon.degrees) % 360.0
         mpPercent = mpDegree / 360
 
-        return mpIllumination, mpDegree, mpPercent
+        locObserver = loc.at(self.app.mount.obsSite.timeJD)
+        moonApparent = locObserver.observe(moon).apparent()
+        sunApparent = locObserver.observe(sun).apparent()
+        moonAngle = position_angle_of(moonApparent.altaz(), sunApparent.altaz())
+
+        return mpIllumination, mpDegree, mpPercent, moonAngle
 
     @staticmethod
     def generateMoonMask(width, height, mpDegree):
@@ -309,7 +320,7 @@ class Almanac:
 
         :return: true for test purpose
         """
-        mpIllumination, mpDegree, mpPercent = self.calcMoonPhase()
+        mpIllumination, mpDegree, mpPercent, mAngle = self.calcMoonPhase()
 
         self.ui.moonPhaseIllumination.setText(f'{mpIllumination * 100:3.2f}')
         self.ui.moonPhasePercent.setText(f'{100* mpPercent:3.0f}')
