@@ -63,6 +63,7 @@ class ManageModel(object):
         self.ui.targetRMS.valueChanged.connect(self.showModelPosition)
         self.ui.targetRMS.valueChanged.connect(self.showErrorAscending)
         self.ui.targetRMS.valueChanged.connect(self.showErrorDistribution)
+        self.app.colorChange.connect(self.colorChangeManageModel)
 
     def initConfig(self):
         """
@@ -95,6 +96,15 @@ class ManageModel(object):
         config['autoUpdateActualAnalyse'] = self.ui.autoUpdateActualAnalyse.isChecked()
         return True
 
+    def colorChangeManageModel(self):
+        """
+        :return:
+        """
+        self.showModelPosition()
+        self.showErrorAscending()
+        self.showErrorDistribution()
+        return True
+
     def setNameList(self, model):
         """
         setNameList populates the list of model names in the main window. before
@@ -193,7 +203,6 @@ class ManageModel(object):
             pointsOut = []
 
         name = os.path.splitext(os.path.basename(self.fittedModelPath))[0]
-
         return name, pointsIn, pointsOut
 
     def showModelPosition(self):
@@ -210,7 +219,6 @@ class ManageModel(object):
         model = self.app.mount.model
         if model is None:
             hasNoStars = True
-
         else:
             hasNoStars = model.starList is None or not model.starList
 
@@ -285,13 +293,11 @@ class ManageModel(object):
         model = self.app.mount.model
         if model is None:
             hasNoStars = True
-
         else:
             hasNoStars = model.starList is None or not model.starList
 
         axe, _ = self.generateFlat(widget=self.errorAscendingPlot,
                                    title='Model Point Errors in ascending order')
-
         if hasNoStars:
             axe.figure.canvas.draw()
             return False
@@ -304,7 +310,6 @@ class ManageModel(object):
                        color=self.M_BLUE,
                        fontweight='bold',
                        fontsize=12)
-
         errors = [star.errorRMS for star in model.starList]
         errors.sort()
         index = range(0, len(errors))
@@ -319,10 +324,8 @@ class ManageModel(object):
         axe.plot([0, len(index) - 1],
                  [value, value],
                  lw=3,
-                 color=self.M_PINK_H)
-
+                 color=self.M_PINK)
         axe.figure.canvas.draw()
-
         return True
 
     def showErrorDistribution(self):
@@ -340,20 +343,17 @@ class ManageModel(object):
         model = self.app.mount.model
         if model is None:
             hasNoStars = True
-
         else:
             hasNoStars = model.starList is None or not model.starList
 
         axe, _ = self.generatePolar(widget=self.errorDistributionPlot,
                                     title='Error Distribution')
-
         if hasNoStars:
             axe.figure.canvas.draw()
             return False
 
         angles = [star.errorAngle.degrees / 180.0 * np.pi for star in model.starList]
         errors = [star.errorRMS for star in model.starList]
-
         axe.plot(angles,
                  errors,
                  marker='.',
@@ -366,17 +366,16 @@ class ManageModel(object):
         axe.plot(angles,
                  values,
                  lw=3,
-                 color=self.M_PINK_H)
-
+                 color=self.M_PINK)
         axe.figure.canvas.draw()
-
         return True
 
     def clearRefreshName(self):
         """
         :return: True for test purpose
         """
-        self.changeStyleDynamic(self.ui.refreshName, 'running', 'false')
+        self.changeStyleDynamic(self.ui.refreshName, 'running', False)
+        self.changeStyleDynamic(self.ui.modelNameGroup, 'running', False)
         self.ui.deleteName.setEnabled(True)
         self.ui.saveName.setEnabled(True)
         self.ui.loadName.setEnabled(True)
@@ -398,7 +397,8 @@ class ManageModel(object):
         self.ui.deleteName.setEnabled(False)
         self.ui.saveName.setEnabled(False)
         self.ui.loadName.setEnabled(False)
-        self.changeStyleDynamic(self.ui.refreshName, 'running', 'true')
+        self.changeStyleDynamic(self.ui.refreshName, 'running', True)
+        self.changeStyleDynamic(self.ui.modelNameGroup, 'running', True)
         self.app.mount.getNames()
         return True
 
@@ -416,10 +416,10 @@ class ManageModel(object):
         modelName = self.ui.nameList.currentItem().text()
         suc = self.app.mount.model.loadName(modelName)
         if not suc:
-            self.app.message.emit('Model [{0}] cannot be loaded'.format(modelName), 2)
+            self.app.message.emit(f'Model load failed:   [{modelName}]', 2)
             return False
         else:
-            self.app.message.emit('Model [{0}] loaded'.format(modelName), 0)
+            self.app.message.emit(f'Model loaded:        [{modelName}]', 0)
             self.refreshModel()
             return True
 
@@ -516,7 +516,8 @@ class ManageModel(object):
         """
         :return: True for test purpose
         """
-        self.changeStyleDynamic(self.ui.refreshModel, 'running', 'false')
+        self.changeStyleDynamic(self.ui.refreshModel, 'running', False)
+        self.changeStyleDynamic(self.ui.modelGroup, 'running', False)
         self.ui.deleteWorstPoint.setEnabled(True)
         self.ui.runOptimize.setEnabled(True)
         self.ui.cancelOptimize.setEnabled(True)
@@ -549,7 +550,8 @@ class ManageModel(object):
 
         :return: True for test purpose
         """
-        self.changeStyleDynamic(self.ui.refreshModel, 'running', 'true')
+        self.changeStyleDynamic(self.ui.refreshModel, 'running', True)
+        self.changeStyleDynamic(self.ui.modelGroup, 'running', True)
         self.app.mount.signals.alignDone.connect(self.clearRefreshModel)
         self.ui.deleteWorstPoint.setEnabled(False)
         self.ui.runOptimize.setEnabled(False)
