@@ -16,15 +16,20 @@
 ###########################################################
 # standard libraries
 import os
+import time
 from pathlib import Path
 
 # external packages
 import PyQt5
+from PyQt5.QtGui import QTextCursor
 from PyQt5.QtTest import QTest
 from astropy.io import fits
 from base.transform import J2000ToJNow
 
 # local import
+from mountcontrol.convert import convertRaToAngle, convertDecToAngle
+from mountcontrol.convert import formatHstrToText, formatDstrToText
+from mountcontrol.connection import Connection
 
 
 class Tools(object):
@@ -97,6 +102,8 @@ class Tools(object):
         self.ui.moveCoordinateDec.textEdited.connect(self.setDEC)
         self.ui.moveCoordinateDec.returnPressed.connect(self.setDEC)
 
+        self.ui.commandInput.returnPressed.connect(self.commandRaw)
+
     def initConfig(self):
         """
         initConfig read the key out of the configuration dict and stores it to the gui
@@ -504,12 +511,12 @@ class Tools(object):
         if not ok:
             return False
 
-        value = self.convertRaToAngle(value)
+        value = convertRaToAngle(value)
         if value is None:
             self.ui.moveCoordinateRaFloat.setText('')
             return False
 
-        text = self.formatHstrToText(value)
+        text = formatHstrToText(value)
         self.ui.moveCoordinateRa.setText(text)
         self.ui.moveCoordinateRaFloat.setText(f'{value.hours:2.4f}')
         return True
@@ -528,12 +535,12 @@ class Tools(object):
         if not ok:
             return False
 
-        value = self.convertDecToAngle(value)
+        value = convertDecToAngle(value)
         if value is None:
             self.ui.moveCoordinateDecFloat.setText('')
             return False
 
-        text = self.formatDstrToText(value)
+        text = formatDstrToText(value)
         self.ui.moveCoordinateDec.setText(text)
         self.ui.moveCoordinateDecFloat.setText(f'{value.degrees:2.4f}')
         return True
@@ -606,12 +613,12 @@ class Tools(object):
         :return:
         """
         value = self.ui.moveCoordinateRa.text()
-        ra = self.convertRaToAngle(value)
+        ra = convertRaToAngle(value)
         if ra is None:
             return False
 
         value = self.ui.moveCoordinateDec.text()
-        dec = self.convertDecToAngle(value)
+        dec = convertDecToAngle(value)
         if dec is None:
             return False
 
@@ -624,3 +631,31 @@ class Tools(object):
                                               dec=decJNow)
         suc = self.slewSelectedTargetWithDome(slewType='keep')
         return suc
+
+    def commandRaw(self):
+        """
+        :return:
+        """
+        host = self.app.mount.host
+        conn = Connection(host)
+        cmd = self.ui.commandInput.text()
+        self.ui.commandStatus.clear()
+        self.ui.commandOutput.clear()
+        startTime = time.time()
+        sucSend, sucRec, val = conn.communicateRaw(cmd)
+        endTime = time.time()
+        delta = endTime - startTime
+        self.ui.commandOutput.clear()
+        if sucSend:
+            t = 'Command OK\n'
+            self.ui.commandStatus.insertPlainText(t)
+        if sucRec:
+            t = f'Receive OK, took {delta:2.3f}s'
+            self.ui.commandStatus.insertPlainText(t)
+        else:
+            t = f'Receive ERROR, took {delta:2.3f}s'
+            self.ui.commandStatus.insertPlainText(t)
+
+        self.ui.commandOutput.insertPlainText(val + '\n')
+        self.ui.commandOutput.moveCursor(QTextCursor.End)
+        return True
