@@ -24,15 +24,9 @@ from base.ascomClass import AscomClass
 
 class CoverAscom(AscomClass):
     """
-    the class Dome inherits all information and handling of the Dome device. there will be
-    some parameters who will define the slewing position of the dome relating to the
-    mount.dome = DomeAscom(app=None)
     """
 
-    __all__ = ['CoverAscom',
-               ]
-
-    CYCLE_POLL_DATA = 1000
+    __all__ = ['CoverAscom']
     coverStates = ['NotPresent', 'Closed', 'Moving', 'Open', 'Unknown', 'Error']
 
     def __init__(self, app=None, signals=None, data=None):
@@ -41,13 +35,6 @@ class CoverAscom(AscomClass):
         self.signals = signals
         self.data = data
 
-    def workerGetInitialConfig(self):
-        """
-        :return: true for test purpose
-        """
-        super().workerGetInitialConfig()
-        return True
-
     def workerPollData(self):
         """
         :return: true for test purpose
