@@ -39,13 +39,16 @@ class DataWriter:
         super().__init__()
         self.app = app
 
-    def writeEarthRotationData(self, installPath=''):
+    def writeEarthRotationData(self, installPath='', updaterApp=''):
         """
         :param installPath:
+        :param updaterApp:
         :return:
         """
         sourceDir = self.app.mwGlob['dataDir'] + '/'
         destDir = installPath + '/'
+        if destDir == sourceDir:
+            return False
 
         if not os.path.isfile(sourceDir + 'CDFLeapSeconds.txt'):
             return False
@@ -53,12 +56,15 @@ class DataWriter:
         if not os.path.isfile(sourceDir + 'finals.data'):
             return False
 
-        if destDir != sourceDir:
+        if not os.path.isfile(sourceDir + 'tai-utc.dat'):
+            return False
+
+        if updaterApp == 'tenmicron_v2.exe':
             shutil.copy(sourceDir + 'CDFLeapSeconds.txt', destDir + 'CDFLeapSeconds.txt')
+        else:
+            shutil.copy(sourceDir + 'tai-utc.dat', destDir + 'tai-utc.dat')
 
-        if destDir != sourceDir:
-            shutil.copy(sourceDir + 'finals.data', destDir + 'finals.data')
-
+        shutil.copy(sourceDir + 'finals.data', destDir + 'finals.data')
         return True
 
     @staticmethod
