@@ -20,30 +20,20 @@
 
 # local imports
 from base.alpacaClass import AlpacaClass
-from base.alpacaBase import ObservingConditions
 
 
 class SkymeterAlpaca(AlpacaClass):
     """
     """
 
-    __all__ = ['SkymeterAlpaca',
-               ]
+    __all__ = ['SkymeterAlpaca']
 
     def __init__(self, app=None, signals=None, data=None):
         super().__init__(app=app, data=data, threadPool=app.threadPool)
 
-        self.client = ObservingConditions()
         self.signals = signals
         self.data = data
 
-    def getInitialConfig(self):
-        """
-        :return: true for test purpose
-        """
-        super().getInitialConfig()
-        return True
-
     def workerPollData(self):
         """
         :return: true for test purpose
@@ -51,6 +41,8 @@ class SkymeterAlpaca(AlpacaClass):
         if not self.deviceConnected:
             return False
 
-        self.data['SKY_QUALITY.SKY_TEMPERATURE'] = self.client.temperature()
-        self.data['SKY_QUALITY.SKY_BRIGHTNESS'] = self.client.skyquality()
+        self.getAndStoreAlpacaProperty('temperature',
+                                       'SKY_QUALITY.SKY_TEMPERATURE')
+        self.getAndStoreAlpacaProperty('skyquality',
+                                       'SKY_QUALITY.SKY_BRIGHTNESS')
         return True
