@@ -24,13 +24,9 @@ from base.ascomClass import AscomClass
 
 class SkymeterAscom(AscomClass):
     """
-    the class SkymeterAscom inherits all information and handling of the Dome device.
-    there will be some parameters who will define the slewing position of the dome relating
-    to the
     """
 
-    __all__ = ['SkymeterAscom',
-               ]
+    __all__ = ['SkymeterAscom']
 
     def __init__(self, app=None, signals=None, data=None):
         super().__init__(app=app, data=data, threadPool=app.threadPool)
@@ -38,13 +34,6 @@ class SkymeterAscom(AscomClass):
         self.signals = signals
         self.data = data
 
-    def workerGetInitialConfig(self):
-        """
-        :return: true for test purpose
-        """
-        super().workerGetInitialConfig()
-        return True
-
     def workerPollData(self):
         """
         :return: true for test purpose
