@@ -24,26 +24,17 @@ from base.indiClass import IndiClass
 
 class SkymeterIndi(IndiClass):
     """
-    the class SkymeterIndi inherits all information and handling of the Skymeter device
-
-        >>> s = SkymeterIndi(app=None)
     """
 
-    __all__ = ['SkymeterIndi',
-               ]
-    UPDATE_RATE = 5
+    __all__ = ['SkymeterIndi']
 
     def __init__(self, app=None, signals=None, data=None):
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-
         self.signals = signals
+        super().__init__(app=app, data=data, threadPool=app.threadPool)
         self.data = data
 
     def setUpdateConfig(self, deviceName):
         """
-        _setUpdateRate corrects the update rate of weather devices to get an defined
-        setting regardless, what is setup in server side.
-
         :param deviceName:
         :return: success
         """
