@@ -26,9 +26,7 @@ class WeatherUPBAscom(AscomClass):
     """
     """
 
-    __all__ = ['WeatherUPBAscom',
-               ]
-    CYCLE_POLL_DATA = 1000
+    __all__ = ['WeatherUPBAscom']
 
     def __init__(self, app=None, signals=None, data=None):
         super().__init__(app=app, data=data, threadPool=app.threadPool)
@@ -36,18 +34,14 @@ class WeatherUPBAscom(AscomClass):
         self.signals = signals
         self.data = data
 
-    def workerGetInitialConfig(self):
-        """
-        :return: true for test purpose
-        """
-        super().workerGetInitialConfig()
-        return True
-
     def workerPollData(self):
         """
         :return: true for test purpose
         """
-        self.getAndStoreAscomProperty('temperature', 'WEATHER_PARAMETERS.WEATHER_TEMPERATURE')
-        self.getAndStoreAscomProperty('dewpoint', 'WEATHER_PARAMETERS.WEATHER_DEWPOINT')
-        self.getAndStoreAscomProperty('humidity', 'WEATHER_PARAMETERS.WEATHER_HUMIDITY')
+        self.getAndStoreAscomProperty('temperature',
+                                      'WEATHER_PARAMETERS.WEATHER_TEMPERATURE')
+        self.getAndStoreAscomProperty('dewpoint',
+                                      'WEATHER_PARAMETERS.WEATHER_DEWPOINT')
+        self.getAndStoreAscomProperty('humidity',
+                                      'WEATHER_PARAMETERS.WEATHER_HUMIDITY')
         return True
